@@ -276,10 +276,16 @@ impl Visit for SpanVisualizer<'_> {
 
     mtd!(SelectorList, visit_selector_list);
 
+    mtd!(CompoundSelectorList, visit_compound_selector_list);
+
+    mtd!(RelativeSelectorList, visit_relative_selector_list);
+
     mtd!(ComplexSelector, visit_complex_selector);
 
     mtd!(Combinator, visit_combinator);
 
+    mtd!(RelativeSelector, visit_relative_selector);
+
     mtd!(CompoundSelector, visit_compound_selector);
 
     mtd!(TypeSelector, visit_type_selector);
@@ -310,12 +316,22 @@ impl Visit for SpanVisualizer<'_> {
 
     mtd!(PseudoClassSelector, visit_pseudo_class_selector);
 
-    mtd!(PseudoElementSelector, visit_pseudo_element_selector);
+    mtd!(
+        PseudoClassSelectorChildren,
+        visit_pseudo_class_selector_children
+    );
 
     mtd!(AnPlusB, visit_an_plus_b);
 
     mtd!(AnPlusBNotation, visit_an_plus_b_notation);
 
+    mtd!(PseudoElementSelector, visit_pseudo_element_selector);
+
+    mtd!(
+        PseudoElementSelectorChildren,
+        visit_pseudo_element_selector_children
+    );
+
     mtd!(Delimiter, visit_delimiter);
 
     mtd!(SimpleBlock, visit_simple_block);
